import { Fragment, isVNode, Comment } from 'vue';
function ensureValidVNode(vnodes) {
    return vnodes.some((child) => {
        if (!isVNode(child)) {
            return true;
        }
        if (child.type === Comment) {
            return false;
        }
        if (child.type === Fragment &&
            !ensureValidVNode(child.children)) {
            return false;
        }
        return true;
    })
        ? vnodes
        : null;
}
/**
 * We shouldn't use the following functions with slot flags `_: 1, 2, 3`
 */
export function resolveSlot(slot, fallback) {
    return (slot && ensureValidVNode(slot())) || fallback();
}
export function resolveSlotWithProps(slot, props, fallback) {
    console.log(slot && ensureValidVNode(slot(props)));
    return (slot && ensureValidVNode(slot(props))) || fallback(props);
}
export function resolveWrappedSlot(slot, wrapper) {
    const children = slot && ensureValidVNode(slot());
    if (children)
        return wrapper(children);
    return null;
}
export function isSlotEmpty(slot) {
    return !(slot && ensureValidVNode(slot()));
}
